{% extends 'base.html' %}

{% block layout %}
<content class="block max-w-3xl mx-auto md:p-12 flex-grow  w-full">
{#    <div class="bg-white rounded-2xl  shadow-black w-full p-8">#}
    <div class="bg-white rounded-2xl md:drop-shadow-2xl shadow-black w-full p-8">

{#    md:drop-shadow-2xl#}

    {% block content %} 
    {% endblock %}

    </div>
</content>
{% endblock %}