{% extends 'base.html' %}
{% load static %}

{% block content %}
    
     <!-- ======= Blog Section ======= -->
     <section class="breadcrumbs">
        <div class="container">
  
          <div class="d-flex justify-content-between align-items-center">
            <h2>Home</h2>
  
            <ol>
              <li><a href="{% url 'home' %}">Home</a></li>              
            </ol>
          </div>
  
        </div>
      </section><!-- End Blog Section -->
  
      <!-- ======= Blog Section ======= -->
      <section id="blog" class="blog">
        <div class="container" >
  
          <div class="row">
  
            <div class="col-lg-8 entries">
            <!--   blog   list -->
            </div>
  
            <div class="col-lg-4">
  
              {% block sidebar %}
                {% include 'sidebar.html' %}
              {% endblock sidebar %}
  
            </div><!-- End blog sidebar -->
  
          </div>
  
        </div>
      </section><!-- End Blog Section -->

{% endblock content %}