{% extends 'layouts/blank.html' %}

{% block content %}

<div class="max-w-4xl mx-auto px-8 py-24 text-center">
    <h1 class="text-6xl">Page not found</h1>
    <p class="my-10 text-gray-500">
        Error 404: This page doesn't exist or is unavailable
    </p>
</div>

{% endblock %}